import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/screens/home/content.dart';
import 'package:furman_now/src/screens/home/state.dart';
import 'package:provider/provider.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({Key? key}) : super(key: key);

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  final ScrollController _controller = ScrollController();

  double overscrollTopAmount = 0;
  double overscrollBottomAmount = 0;

  @override
  void initState() {
    super.initState();

    _controller.addListener(updateScrollPosition);
  }

  updateScrollPosition() {
    // bottom overscroll
    if (_controller.position.pixels > _controller.position.maxScrollExtent) {
      setState(() {
        overscrollBottomAmount =
            _controller.position.pixels - _controller.position.maxScrollExtent;
      });
    } else {
      if (overscrollBottomAmount != 0) {
        setState(() {
          overscrollBottomAmount = 0;
        });
      }
    }

    // top overscroll
    if (_controller.position.pixels < 0) {
      setState(() {
        overscrollTopAmount =
            _controller.position.pixels.abs();
      });
    } else {
      if (overscrollTopAmount != 0) {
        setState(() {
          overscrollTopAmount = 0;
        });
      }
    }
  }

  handleScrollEvent(BuildContext context) {
    const scrollMessageSensitivity = 20;
    const pageSwitchSensitivity = 60;
    var offsetAmount = overscrollTopAmount.abs();

    if (overscrollTopAmount != 0) {
      if (offsetAmount > pageSwitchSensitivity) {
        context.router.navigate(const StudentIdRoute());
        context.read<HomePageState>().collapse = true;
      } else if (offsetAmount > scrollMessageSensitivity) {
        context.read<HomePageState>().showScrollMessage = true;
      } else {
        context.read<HomePageState>().showScrollMessage = false;
      }
    } else {
      context.read<HomePageState>().showScrollMessage = false;

      if (_controller.position.pixels > pageSwitchSensitivity) {
        context.router.navigate(const HomeRoute());
        context.read<HomePageState>().collapse = false;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => HomePageState(),
      builder: (context, _) => Scaffold(
          body: AnnotatedRegion<SystemUiOverlayStyle>(
            value: SystemUiOverlayStyle.light,
            child: Container(
              color: const Color(0xffb7acc9),
              child: SafeArea(
                child: Container(
                  color: const Color(0xffb7acc9),
                  child: Stack(
                    fit: StackFit.loose,
                    children: [
                      // overscroll indicator color
                      Align(
                        alignment: Alignment.bottomCenter,
                        child: Container(
                          height: overscrollBottomAmount + 30,
                          color: Colors.grey.shade50,
                        ),
                      ),
                      const AutoTabsRouter(
                        routes: [
                          HomeRoute(),
                          StudentIdRoute(),
                        ],
                      ),
                      NotificationListener<ScrollNotification>(
                        onNotification: (notification) {
                          if (notification is ScrollUpdateNotification) {
                            handleScrollEvent(context);
                          }
                          return true;
                        },
                        child: Consumer<HomePageState>(
                          builder: (context, state, _) =>
                            ClipRect(child: HomeContent(
                              controller: _controller,
                              collapse: state.collapse,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ),
    );
  }
}

