import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:furman_now/src/layouts/app_page.dart';
import 'package:furman_now/src/services/info/health_safety_service.dart';
import 'package:furman_now/src/widgets/info/info_card.dart';

class HealthSafetyScreen extends StatelessWidget {
  const HealthSafetyScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppPageLayout(
      title: "Health and Safety",
      icon: FlutterRemix.arrow_left_line,
      backgroundColor: Colors.red.shade50,
      iconTapAction: () => context.router.pop(),
      content: Padding(
        padding: const EdgeInsets.all(20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Center(
              child: Padding(
                padding: const EdgeInsets.only(top: 15, bottom: 35),
                child: Text(
                  "If you are in an emergency, dial 911",
                  style: Theme.of(context).textTheme.titleMedium?.copyWith(
                    color: Colors.red.shade800,
                  ),
                ),
              ),
            ),
            FutureBuilder<Iterable<HealthSafetyInfo>>(
              future: HealthSafetyService.fetchHealthSafetyInfo(),
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  var items = snapshot.data!.where((item) =>
                    item.type != HealthSafetyInfoType.removed
                  );
                  var iconMap = {
                    HealthSafetyInfoType.phone: FlutterRemix.phone_line,
                    HealthSafetyInfoType.link: FlutterRemix.external_link_line,
                    HealthSafetyInfoType.app: FlutterRemix.apps_line,
                  };
                  return Column(
                    children: items.map((item) {
                      return Padding(
                        padding: const EdgeInsets.only(bottom: 15),
                        child: InfoCard(
                          title: item.name,
                          icon: item.icon,
                          items: [
                            InfoCardItem(
                              name: item.linkText,
                              icon: iconMap[item.type] ?? FlutterRemix.link
                            ),
                          ],
                          onClick: () => item.launch(),
                        ),
                      );
                    }).toList());
                }
                else if (snapshot.hasError) {
                  return Text(
                    '${snapshot.error}', style: const TextStyle(color: Colors.red),);
                }
                // By default, show a loading spinner.
                return const Center(
                  child: Padding(
                      padding: EdgeInsets.symmetric(vertical: 25),
                      child: CircularProgressIndicator()
                  ),
                );
              },
            ),
          ],
        ),
      )
    );
  }
}
