import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/screens/map/state.dart';
import 'package:furman_now/src/utils/theme.dart';

class MapHeader extends StatelessWidget {
  final String? activeCategory;

  const MapHeader({
    this.activeCategory,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 12),
      child: Container(
        width: double.infinity,
        height: 50,
        padding: const EdgeInsets.only(left: 10, right: 20),
        decoration: const BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.all(Radius.circular(60)),
          boxShadow: [
            BoxShadow(
              color: Color(0x33000000),
              blurRadius: 8,
            ),
          ],
        ),
        child: Stack(
          children: [
            Align(
              alignment: Alignment.centerLeft,
              child: AnimatedCrossFade(
                duration: const Duration(milliseconds: 300),
                crossFadeState: activeCategory == null ? CrossFadeState.showFirst : CrossFadeState.showSecond,
                firstChild: GestureDetector(
                  onTapDown: (e) => context.router.push(MapCategoryRoute(
                    category: MapCategory(
                      name: "Restaurants",
                      icon: FlutterRemix.restaurant_line,
                      activator: () => null,
                    ),
                  )),
                  child: Wrap(
                    crossAxisAlignment: WrapCrossAlignment.center,
                    children: [
                      SvgPicture.asset("assets/images/bell-tower.svg", color: Theme.of(context).primaryColor, height: 32),
                      const SizedBox(width: 10),
                      Text(
                        "Search locations",
                        style: furmanTextStyle(TextStyle(
                          fontSize: 18,
                          fontWeight: FontWeight.w500,
                          color: Colors.grey.shade500,
                        )),
                      ),
                    ],
                  ),
                ),
                secondChild: Wrap(
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    GestureDetector(
                      onTapDown: (e) => context.router.navigateBack(),
                      child: Icon(FlutterRemix.arrow_left_line, size: 28, color: Colors.grey.shade800,),
                    ),
                    const SizedBox(width: 10),
                    if (activeCategory != null)
                      Text(
                        activeCategory!,
                        style: furmanTextStyle(TextStyle(
                          fontSize: 18,
                          fontWeight: FontWeight.w600,
                          color: Colors.grey.shade800,
                        )),
                      ),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
